==> squid3_3.3.8.orig.tar.bz2: squid-3.3.8/src/acl/Data.h <==
/*
 *
 * SQUID Web Proxy Cache          http://www.squid-cache.org/
 * ----------------------------------------------------------
 *
 *  Squid is the result of efforts by numerous individuals from
 *  the Internet community; see the CONTRIBUTORS file for full
 *  details.   Many organizations have provided support for Squid's
 *  development; see the SPONSORS file for full details.  Squid is
 *  Copyrighted (C) 2001 by the Regents of the University of
 *  California; see the COPYRIGHT file for full details.  Squid
 *  incorporates software developed and/or copyrighted by other
 *  sources; see the CREDITS file for full details.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 *
 * Copyright (c) 2003, Robert Collins <robertc@squid-cache.org>
 */
#ifndef SQUID_ACLDATA_H
#define SQUID_ACLDATA_H

class wordlist;

/// \ingroup ACLAPI
template <class M>
class ACLData
{

public:

    virtual ~ACLData() {}

    virtual bool match(M) =0;
    virtual wordlist *dump() =0;
    virtual void parse() =0;
    virtual ACLData *clone() const =0;
    virtual void prepareForUse() {}

    virtual bool empty() const =0;
};

#endif /* SQUID_ACLDATA_H */

==> squid3_3.4.8.orig.tar.bz2: squid-3.4.8/src/acl/Data.h <==
/*
 *
 * SQUID Web Proxy Cache          http://www.squid-cache.org/
 * ----------------------------------------------------------
 *
 *  Squid is the result of efforts by numerous individuals from
 *  the Internet community; see the CONTRIBUTORS file for full
 *  details.   Many organizations have provided support for Squid's
 *  development; see the SPONSORS file for full details.  Squid is
 *  Copyrighted (C) 2001 by the Regents of the University of
 *  California; see the COPYRIGHT file for full details.  Squid
 *  incorporates software developed and/or copyrighted by other
 *  sources; see the CREDITS file for full details.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 *
 * Copyright (c) 2003, Robert Collins <robertc@squid-cache.org>
 */
#ifndef SQUID_ACLDATA_H
#define SQUID_ACLDATA_H

class wordlist;
extern char *xstrtok(char *str, const char *delimiters);

/// \ingroup ACLAPI
template <class M>
class ACLData
{

public:

    virtual ~ACLData() {}

    virtual bool match(M) =0;
    virtual wordlist *dump() =0;
    virtual void parse() =0;
    virtual ACLData *clone() const =0;
    virtual void prepareForUse() {}

    virtual bool empty() const =0;

    /// XXX: Temporary hack to allow old ACL code to handle quoted values without
    /// replacing every strtok() call.
    char *strtok(char *str, const char *dels) { return xstrtok(str, dels); }
};

#endif /* SQUID_ACLDATA_H */
